==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/imageplugin/.rcc/qrc_imageplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/imageplugin/imageplugin.gif
  0x0,0x0,0x1,0xa,
  0x47,
  0x49,0x46,0x38,0x39,0x61,0x14,0x0,0x14,0x0,0xc4,0x0,0x0,0x64,0x97,0x3d,0xc1,
  0xdc,0xbe,0x94,0xab,0xd0,0xe9,0xf0,0xf7,0x5e,0x91,0x8b,0xb1,0xc0,0xda,0x86,0xbf,
  0x55,0xc4,0xd3,0xae,0x7f,0xb4,0xa8,0x79,0xa9,0x4d,0xd3,0x9e,0x53,0x80,0xa3,0xda,
  0xa0,0xcc,0x92,0xa1,0xb4,0xd3,0xa5,0x7f,0x3a,0x7c,0xa1,0xc4,0xed,0xef,0xf1,0x99,
  0xcc,0x66,0x92,0xc1,0x87,0x7a,0xaa,0x6a,0x8d,0xad,0xe0,0x75,0x81,0x5d,0x89,0xbc,
  0x64,0xf2,0xf5,0xf7,0x69,0x98,0xa4,0x85,0x8d,0x43,0x9a,0xb7,0xe5,0xa7,0xd2,0x73,
  0x9a,0xaf,0xd0,0xc9,0xd3,0xe4,0xd1,0xae,0x6d,0xff,0xff,0xff,0x21,0xf9,0x4,0x1,
  0x7,0x0,0x1f,0x0,0x2c,0x0,0x0,0x0,0x0,0x14,0x0,0x14,0x0,0x0,0x5,0x87,
  0xe0,0x27,0x8e,0x64,0x69,0x9e,0x68,0xaa,0xa2,0x5d,0xc3,0x9,0x70,0x1c,0x73,0x9d,
  0xd9,0x40,0x57,0xae,0xef,0x10,0x67,0x72,0x17,0x8d,0x0,0xc1,0x28,0x4a,0x30,0x8f,
  0xc5,0xc0,0x57,0x12,0x4,0x89,0x9b,0x88,0xf4,0xa8,0x64,0x92,0x9c,0x1a,0x62,0xc4,
  0xc0,0xb5,0x10,0xaa,0x26,0x2c,0x62,0xc3,0xed,0x7e,0x97,0xe1,0xa7,0xc4,0x52,0x9e,
  0x60,0xc0,0xcd,0x20,0x7,0x31,0xb1,0x58,0x26,0x84,0x7,0x5,0xdd,0x1c,0x68,0x84,
  0x15,0x19,0x19,0x15,0x7a,0x7b,0x56,0x23,0x2,0x3,0x9,0x8b,0xe,0xa,0xa,0xe,
  0x0,0x91,0x7c,0x57,0x3,0x1,0x96,0x7,0x7,0x1e,0x96,0x96,0x93,0x88,0x95,0x9b,
  0xa0,0x9c,0x87,0x22,0x37,0x3b,0xa6,0x17,0x3d,0x26,0x1d,0x5,0x1c,0xad,0xae,0xaf,
  0x34,0x2b,0xb2,0xb3,0xb4,0xb3,0x21,0x0,0x3b,
  
};

static const unsigned char qt_resource_name[] = {
  // imageplugin
  0x0,0xb,
  0xc,0x93,0xd2,0x5e,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,0x0,0x6e,
    // imageplugin.gif
  0x0,0xf,
  0x2,0x78,0x6a,0x56,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x67,0x0,0x69,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/imageplugin
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/imageplugin/imageplugin.gif
  0x0,0x0,0x0,0x1c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_imageplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_imageplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imageplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imageplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_imageplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imageplugin)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/imageplugin/.rcc/qrc_imageplugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/imageplugin/imageplugin.gif
  0x0,0x0,0x1,0xa,
  0x47,
  0x49,0x46,0x38,0x39,0x61,0x14,0x0,0x14,0x0,0xc4,0x0,0x0,0x64,0x97,0x3d,0xc1,
  0xdc,0xbe,0x94,0xab,0xd0,0xe9,0xf0,0xf7,0x5e,0x91,0x8b,0xb1,0xc0,0xda,0x86,0xbf,
  0x55,0xc4,0xd3,0xae,0x7f,0xb4,0xa8,0x79,0xa9,0x4d,0xd3,0x9e,0x53,0x80,0xa3,0xda,
  0xa0,0xcc,0x92,0xa1,0xb4,0xd3,0xa5,0x7f,0x3a,0x7c,0xa1,0xc4,0xed,0xef,0xf1,0x99,
  0xcc,0x66,0x92,0xc1,0x87,0x7a,0xaa,0x6a,0x8d,0xad,0xe0,0x75,0x81,0x5d,0x89,0xbc,
  0x64,0xf2,0xf5,0xf7,0x69,0x98,0xa4,0x85,0x8d,0x43,0x9a,0xb7,0xe5,0xa7,0xd2,0x73,
  0x9a,0xaf,0xd0,0xc9,0xd3,0xe4,0xd1,0xae,0x6d,0xff,0xff,0xff,0x21,0xf9,0x4,0x1,
  0x7,0x0,0x1f,0x0,0x2c,0x0,0x0,0x0,0x0,0x14,0x0,0x14,0x0,0x0,0x5,0x87,
  0xe0,0x27,0x8e,0x64,0x69,0x9e,0x68,0xaa,0xa2,0x5d,0xc3,0x9,0x70,0x1c,0x73,0x9d,
  0xd9,0x40,0x57,0xae,0xef,0x10,0x67,0x72,0x17,0x8d,0x0,0xc1,0x28,0x4a,0x30,0x8f,
  0xc5,0xc0,0x57,0x12,0x4,0x89,0x9b,0x88,0xf4,0xa8,0x64,0x92,0x9c,0x1a,0x62,0xc4,
  0xc0,0xb5,0x10,0xaa,0x26,0x2c,0x62,0xc3,0xed,0x7e,0x97,0xe1,0xa7,0xc4,0x52,0x9e,
  0x60,0xc0,0xcd,0x20,0x7,0x31,0xb1,0x58,0x26,0x84,0x7,0x5,0xdd,0x1c,0x68,0x84,
  0x15,0x19,0x19,0x15,0x7a,0x7b,0x56,0x23,0x2,0x3,0x9,0x8b,0xe,0xa,0xa,0xe,
  0x0,0x91,0x7c,0x57,0x3,0x1,0x96,0x7,0x7,0x1e,0x96,0x96,0x93,0x88,0x95,0x9b,
  0xa0,0x9c,0x87,0x22,0x37,0x3b,0xa6,0x17,0x3d,0x26,0x1d,0x5,0x1c,0xad,0xae,0xaf,
  0x34,0x2b,0xb2,0xb3,0xb4,0xb3,0x21,0x0,0x3b,
  
};

static const unsigned char qt_resource_name[] = {
  // imageplugin
  0x0,0xb,
  0xc,0x93,0xd2,0x5e,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,0x0,0x6e,
    // imageplugin.gif
  0x0,0xf,
  0x2,0x78,0x6a,0x56,
  0x0,0x69,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x70,0x0,0x6c,0x0,0x75,0x0,0x67,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x67,0x0,0x69,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/imageplugin
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/imageplugin/imageplugin.gif
  0x0,0x0,0x0,0x1c,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_imageplugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_imageplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imageplugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imageplugin)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_imageplugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_imageplugin)(); }
   } dummy;
}
